==> freshmaker-0.0.2.tar.gz: freshmaker-0.0.2/freshmaker/parsers/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2016  Red Hat, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# Written by Jan Kaluza <jkaluza@redhat.com>

import abc


class BaseParser(object):
    """
    Abstract parser class parsing fedmsg messages and generating triggers.
    """
    __metaclass__ = abc.ABCMeta
    name = "abstract_parser"
    topic_suffixes = []

    @abc.abstractmethod
    def can_parse(self, topic, msg):
        """
        Returns True when msg can be parsed by this class.
        """
        raise NotImplementedError()

    @abc.abstractmethod
    def parse(self, topic, msg):
        """
        Parses the message and returns BaseTrigger object.
        """
        raise NotImplementedError()

==> freshmaker-0.0.7.tar.gz: freshmaker-0.0.7/freshmaker/parsers/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2016  Red Hat, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# Written by Jan Kaluza <jkaluza@redhat.com>

import abc


class BaseParser(object):
    """
    Abstract parser class parsing fedmsg messages and generating events.
    """
    __metaclass__ = abc.ABCMeta
    name = "abstract_parser"
    topic_suffixes = []

    @abc.abstractmethod
    def can_parse(self, topic, msg):
        """
        Returns True when msg can be parsed by this class.
        """
        raise NotImplementedError()

    @abc.abstractmethod
    def parse(self, topic, msg):
        """
        Parses the message and returns BaseEvent object.
        """
        raise NotImplementedError()
